trendPlot<-function(stat, ...){

  # Correct type of data
  if(stat$RankingType=="PoissonRegression" | stat$RankingType=="PoissonGroups"){
  
    # Category results
    if(is.null(stat$Category)){
      # Regression
      if(!is.null(stat$covariates)){
        trendPlot.family(stat, ...)
      # Groups
      } else if(!is.null(stat$groups)){
        groupPlot.family(stat, ...)
      }
    # Family results
    } else {
      # Regression
      if(!is.null(stat$covariates)){
        trendPlot.category(stat, ...)
      # Groups
      } else if(!is.null(stat$groups)){
        groupPlot.category(stat, ...)
      }    
    }    
  }
}
 
groupPlot<-function(stat, ...){
  trendPlot(stat, ...)
}

trendPlot.category<-function(stat.cat, category, x.axis.lab=NULL, xlim, ylim, 
                             col.points="black", col.trend="red3",
			     xlab="", plot.counts=TRUE, main,
	                     print.pvalue=FALSE, print.pvalue.pos="topright", print.pvalue.cex=1.3, 
			     add=FALSE, ...){
  

  if(stat.cat$RankingType!="PoissonRegression"){
    stop(sprintf("This function only works with Poisson regression (current ranking type is %s).", stat.cat$RankingType))
  }
  
  if(missing(category)){
    stop("You need to specify a category.")
  }
  
  Categories<-getCategory(stat.cat$Category, stat.cat$Type)
  
  if(category<1 | category>length(Categories)){
    stop(sprintf("Category %s not found.", category))
  }
 
  cur.data<-stat.cat$Ranking.details$counts[[category]]
  nGeneFamilies<-dim(cur.data)[1]
  counts.total<-stat.cat$Ranking.details$TotalCounts

  cur.rate<-t(t(cur.data)/counts.total)
  cur.rate<-as.data.frame(cur.rate) 

  cur.rate<-cur.rate/exp(stat.cat$Ranking.details$offset[[category]])

  if(missing(xlim)){  
    xlim<-c(min(stat.cat$covariates), max(stat.cat$covariates))
  }

  if(missing(ylim)){  
    ylim<-c(0, max(cur.rate))
  }

  if(missing(main)){
    main<-sprintf("%s - %s", category, names(Categories)[category])
  }

  if(add==FALSE){  
    plot(NULL, xlim=xlim, ylim=ylim, axes=FALSE, ylab="Normalized relative frequency", xlab=xlab, main=main, cex.lab=1.3, cex.main=1.3, ...)
    
    if(is.null(x.axis.lab)){
      if(!is.null(stat.cat$covariates.antilog)){
        x.axis.lab<-round(stat.cat$covariates.antilog, digits=2)
      } else { 
        x.axis.lab<-round(stat.cat$covariates, digits=2)
      }
    }    
    axis(1, at=stat.cat$covariates, labels=x.axis.lab, lwd=2)
    
    y.seq<-seq(ylim[1], ylim[2], length=5)    
    axis(2, at=y.seq, labels=sprintf("%0.2f", y.seq), lwd=2, las=1, line=-1)
 
  }
  
  for(i in 1:nGeneFamilies){
      points(x=stat.cat$covariates, y=cur.rate[i,], col=col.points, pch=19, cex=1.1)
  }
  
  curve<-exp(stat.cat$Ranking.details$coef[category]*stat.cat$covariates)

  lines(y=curve, x=stat.cat$covariates, col=col.trend, lwd=3)

  if(print.pvalue==TRUE){
    p.value<-stat.cat$Ranking.details$pvalue[category]
    legend(x=print.pvalue.pos, legend=sprintf("P-value = %0.1e", p.value), bty="n", cex=print.pvalue.cex)
  }
   
}

trendPlot.family<-function(stat.families, family, x.axis.lab=NULL, xlim, ylim,
                           col.points="black", col.text="grey30", col.trend="red3",
                           xlab="", plot.counts=TRUE, main, 
			   print.pvalue=FALSE, print.pvalue.pos="topright", print.pvalue.cex=1.3, 
			   add=FALSE, ...){

  if(stat.families$RankingType!="PoissonRegression"){
    stop(sprintf("This function only works with Poisson regression (current ranking type is %s).", stat.families$RankingType))
  }
  
  if(missing(family)){
    stop("You need to specify a family.")
  }
   
  family.select<-stat.families$Annotation[,1]==family
  
  if(sum(family.select, na.rm=TRUE)==0){
    stop(sprintf("Gene family %s not found.", family))
  }  
  
   if(missing(xlim)){
    xlim<-c(min(stat.families$covariates), max(stat.families$covariates))
  }

  if(missing(main)){
    main<-stat.families$Annotation[stat.families$Annotation[,1]==family,2]
  }
  
    
  cur.data<-stat.families$Data[family.select,]
  counts.total<-apply(stat.families$Data, 2, sum)
  cur.rate<-cur.data/counts.total
  
  if(missing(ylim)){  
    ylim<-c(0, max(cur.rate))
  }
    
  if(add==FALSE){
    plot(NULL, xlim=xlim, ylim=ylim, axes=FALSE, ylab="Normalized relative frequency", xlab=xlab, main=main, cex.lab=1.3, cex.main=1.3, ...)
    
    if(is.null(x.axis.lab)){
      if(!is.null(stat.families$covariates.antilog)){
        x.axis.lab<-round(stat.families$covariates.antilog, digits=2)
      } else { 
        x.axis.lab<-round(stat.families$covariates, digits=2)
      }
    }    
    axis(1, at=stat.families$covariates, labels=x.axis.lab, lwd=2)
    
    y.seq<-seq(ylim[1], ylim[2], length=5)    
    axis(2, at=y.seq, labels=sprintf("%0.2f", y.seq), lwd=2, las=1, line=-1)
 
 }
  
  points(x=stat.families$covariates, y=cur.rate, col=col.points, pch=19, cex=1.3)
  
  if(plot.counts==TRUE){
    text(x=stat.families$covariates, y=cur.rate, labels=cur.data, cex=1.2, pos=4, col=col.text)
  }
  
 
  curve<-exp(stat.families$Ranking.details$coef[family.select,"Coef1"])*exp(stat.families$Ranking.details$coef[family.select, "Coef2"]*sort(stat.families$covariates))
  lines(y=curve, x=sort(stat.families$covariates), col=col.trend, lwd=3)

  if(print.pvalue==TRUE){
#    p.value<-anova.glm(res.po$fit, test="Chisq")["Coef2", 5]
    p.value<-stat.families$Ranking.details$pvalue[family.select]
    legend(x=print.pvalue.pos, legend=sprintf("P-value = %0.1e", p.value), bty="n", cex=print.pvalue.cex)
  }
      
}


groupPlot.category<-function(stat.cat, category, ylim, col=c("mistyrose", "lavender", "red3", "royalblue3"), xlab="", 
                           main, print.pvalue=FALSE, print.pvalue.pos="topright", print.pvalue.cex=1.3){

  if(stat.cat$RankingType!="PoissonGroups"){
    stop("This procedure is only applicable to results form direction comparison of groups within the Poisson model.")
  }
  
  if(missing(category)){  
    stop("You need to specify a category.")
  }
  
  Categories<-getCategory(stat.cat$Category, stat.cat$Type)
 
  if(category<1 | category>length(Categories)){
    stop(sprintf("Category %s not found.", category))
  }
 
  cur.data<-stat.cat$Ranking.details$counts[[category]]
  counts.total<-stat.cat$Ranking.details$TotalCounts
  nGeneFamilies<-dim(cur.data)[1]

  cur.rate<-cur.data/counts.total
  cur.rate<-t(t(cur.data)/counts.total)
  cur.rate<-as.data.frame(cur.rate)

  cur.rate<-cur.rate/exp(stat.cat$Ranking.details$offset[[category]])

  g.unique<-unique(stat.cat$groups)
  cols<-rep(col[1], length(stat.cat$groups))
  cols[stat.cat$groups==g.unique[1]]<-col[2]
  cols<-rep(cols, each=nGeneFamilies)

  cols.line<-rep(col[3], length(stat.cat$groups))
  cols.line[stat.cat$groups==g.unique[1]]<-col[4]
#  cols.line<-rep(cols.line, each=nGeneFamilies)

  if(missing(main)){
    main<-names(Categories)[category]  
  }

  if(missing(ylim)){  
    ylim<-c(0, max(cur.rate*1.1))
  } 
 
  coords<-barplot(as.matrix(cur.rate), beside=TRUE, col=cols, width=1, names.arg=colnames(stat.cat$Data), axes=FALSE, ylim=ylim, ylab="Normalized relative frequency", xlab=xlab, cex.lab=1.3, cex.main=1.3, main=main, plot=FALSE)
  barplot(as.matrix(cur.rate), beside=TRUE, col=cols, width=1, names.arg=colnames(stat.cat$Data), axes=FALSE, ylim=ylim, ylab="Normalized relative frequency", xlab=xlab, cex.lab=1.3, cex.main=1.3, main=main)
  
  for(i in 1:length(stat.cat$groups)){  
    if(stat.cat$groups[i]==g.unique[1]){
      h<-exp(stat.cat$Ranking.detail$coef[category])
    } else { 
      h<-1
    }   
    
    x.coords<-c(min(coords[,i])-0.5-0.5, max(coords[,i])+0.5+0.5)
    lines(x=x.coords, y=c(h,h), lwd=3, lty=1, col=cols.line[i])
    
  }
    
  y.seq<-seq(0, ylim[2], length=5)    
  axis(2, at=y.seq, labels=sprintf("%0.1f", y.seq), lwd=2, las=1, line=-1)

  if(print.pvalue==TRUE){  
    p.value<-stat.cat$Ranking.details$pvalue[category]
    legend(x=print.pvalue.pos, legend=sprintf("P-value = %0.1e", p.value), bty="n", cex=print.pvalue.cex)
  }
    
  return()

}


groupPlot.family<-function(stat.families, family, ylim, col=c("mistyrose", "lavender", "red3", "royalblue3"), xlab="",
                           main, print.pvalue=FALSE, print.pvalue.pos="topright", print.pvalue.cex=1.3){

  if(stat.families$RankingType!="PoissonGroups"){
    stop("This procedure is only applicable to results form direction comparison of groups within the Poisson model.")
  }
  
  if(missing(family)){  
    stop("You need to specify a family.")
  }
  
  family.select<-stat.families$Annotation[,1]==family
  if(sum(family.select)==0){
    stop(sprintf("Gene family %s not found.", family))
  }  
  
  if(missing(main)){
    main<-stat.families$Annotation[stat.families$Annotation[,1]==family,2]
  }  
 
  cur.data<-stat.families$Data[stat.families$Annotation[,1]==family,]  
  counts.total<-apply(stat.families$Data, 2, sum)
  cur.rate<-cur.data/counts.total
 
  cur.rate<-cur.rate/exp(stat.families$Ranking.details$coef[family.select,"Coef1"])
 
#  res.po<-testGeneFamilies.poisson.fit(cur.data, counts.total, stat.families$design.matrix) 
#  cur.rate<-cur.rate/exp(predict.glm(res.po$fit, newdata=res.po$data.mat, type="term", term="Coef1"))
  
  g.unique<-unique(stat.families$groups)
  cols<-rep(col[1], length(stat.families$groups))
  cols[stat.families$groups==g.unique[1]]<-col[2]
  
  cols.line<-rep(col[3], length(stat.families$groups))
  cols.line[stat.families$groups==g.unique[1]]<-col[4]
  

  if(missing(ylim)){  
    ylim<-c(0, max(cur.rate*1.1))
  } 
 
  barplot(as.numeric(cur.rate), col=cols, width=1, names.arg=colnames(stat.families$Data), axes=FALSE, ylim=ylim, ylab="Normalized relative frequency", xlab=xlab, cex.lab=1.3, cex.main=1.3, main=main)
  
 
  for(i in 1:length(stat.families$groups)){  
    if(stat.families$groups[i]==g.unique[1]){
      h<-exp(stat.families$Ranking.detail$coef[family.select,"Coef2"])
    } else { 
      h<-1
    }   
    x.coords<-0.1+c(1.2*i-1-0.2, 1.2*i)
    lines(x=x.coords, y=c(h,h), lwd=3, lty=1, col=cols.line[i])
    x.coords<-0.1+c(1.2*i-0.6)
    text(x=x.coords, y=cur.rate[i]+max(cur.rate)*0.02, labels=cur.data[i], col="grey30", cex=1.2)
    
  }

  y.seq<-seq(0, ylim[2], length=5)    
  axis(2, at=y.seq, labels=sprintf("%0.1f", y.seq), lwd=2, las=1, line=-1)

  if(print.pvalue==TRUE){
    p.value<-stat.families$Ranking.detail[family.select]
    legend(x=print.pvalue.pos, legend=sprintf("P-value = %0.1e", p.value), bty="n", cex=print.pvalue.cex)
  }
    
  return()

}


densityPlot<-function(data, samples=1, log.yaxis=TRUE, color.hist="mistyrose", xlim, ylim, remove.zeros=TRUE, ...){

  if(remove.zeros==TRUE){
    data.hist<-data$Data[data$Data[,samples]>0,samples]
  } else {
    data.hist<-data$Data[,samples]
  }
  
  max.count<-max(data.hist)
  min.count<-min(data.hist)
    
  if(missing(xlim)){
    xlim<-c(0, max.count)
  }

  res.hist<-hist(data.hist, br=seq(min.count, max.count, by=1), plot=FALSE, right=FALSE)
  
  if(log.yaxis==TRUE){
  
    extra<-0.15
    
    res.hist$counts<-log10(res.hist$counts)
    max.yaxis<-max(ceiling(res.hist$counts))
    res.hist$counts<-res.hist$counts+extra
    res.hist$counts[is.infinite(res.hist$counts)]<-0
    
    at.x<-c(0, seq(0,max.yaxis)+extra)
    labels.x<-c(0,10^seq(0,max.yaxis))
    if(missing(ylim)){
      ylim<-c(0, max.yaxis+extra)
    }
  } else { 
  
    max.yaxis<-max(ceiling(res.hist$counts))
    at.x<-seq(0,max.yaxis, length=4)
    labels.x<-round(seq(0, max.yaxis, length=4))
    if(missing(ylim)){
      ylim<-c(0, max.yaxis)    
    }
  }

  plot(res.hist, axes=FALSE, ylab="Number of gene families", xlab="Number of counts", cex.lab=1.2, col=color.hist, ylim=ylim, main=colnames(data$Data)[samples], xlim=xlim, ...)
  axis(2, at=at.x, labels=labels.x, cex.axis=1.2, lwd=1.5, las=1, line=-1)

  axis(1,at=seq(1, xlim[2], length=5), labels=round(seq(1,xlim[2], length=5)), cex.axis=1.2, lwd=1.5,)
 
}

ppPlot<-function(stat, log.pvalues=TRUE, xlim=NULL, ylim=NULL, col="red3", ...){

  n<-dim(stat$Ranking)[1]
  
  if(log.pvalues==TRUE){
    x<-(-log10(ppoints(n=n)))
    y<-(-log10(stat$Ranking[,"P-value"]))
    if(is.null(xlim)){
      xlim<-c(0, ceiling(max(x, na.rm=TRUE)))
    }
    if(is.null(ylim)){

      ylim<-c(0, ceiling(max(y, na.rm=TRUE)))
    }
  } else { 
    x<-ppoints(n=n)
    y<-stat$Ranking[,"P-value"]
    if(is.null(xlim)){
      xlim<-c(0,1)
    }
    if(is.null(ylim)){
      ylim<-c(0,1)
    }
  }  
  
  qqplot(x=x, y=y, axes=FALSE, xlab="Theoretical quantiles", ylab="Observed quantiles", xlim=xlim, ylim=ylim, col=col, pch=19, cex=1.3, cex.lab=1, ...)
  axis(1, lwd=3)
  axis(2, lwd=3)
  abline(0,1, lwd=3, lty=2, col="royalblue3")
}

summarizeData<-function(data, probs=c(0,0.25,0.50,0.75,0.90,1), print.diversity=TRUE){

  n.samples<-dim(data$Data)[2]
  n.families<-dim(data$Data)[1]
  n.probs<-length(probs)
  
  dist<-c()

  cat("Summary\n\n")

  cat(sprintf("Gene family type: %s\n", data$Type))
  cat(sprintf("Number of samples: %s\n", n.samples))
  cat(sprintf("Samples: %s\n", paste(colnames(data$Data), collapse=",")))
  cat("\n") 

  sum.data<-apply(data$Data,2,sum)
  mean.data<-apply(data$Data,2,mean)
  stdev.data<-sqrt(apply(data$Data,2,var))
  
  cat(sprintf("%-15s", "Sample"))
  for(i in 1:n.samples){
    cat(sprintf("%7.d", i))
  }
  cat(sprintf("\n%-15s", "Total counts"))
  for(i in 1:n.samples){
    cat(sprintf("%7.d", sum.data[i]))
  }
  cat(sprintf("\n%-15s", "Mean counts"))
  for(i in 1:n.samples){
    cat(sprintf("%7.1f", mean.data[i]))
  }
  cat(sprintf("\n%-15s", "Standard dev."))
  for(i in 1:n.samples){
    cat(sprintf("%7.1f", stdev.data[i]))
  }
  cat(sprintf("\n%-15s", "Zeros"))
  for(i in 1:n.samples){
    cat(sprintf("%7d", sum(data$Data[,i]==0)))        
  }
  cat(sprintf("\n%-15s", "Zeros (%)"))
  for(i in 1:n.samples){
    cat(sprintf("%7.1f", 100*sum(data$Data[,i]==0)/n.families))
  }
 
  
  cat(sprintf("\n\n%-11s", "Quantiles"))
  for(j in 1:n.probs){
    if(probs[j]==0){
      cat(sprintf("%7s", "Min"))
    } else if (probs[j]==1){
      cat(sprintf("%7s", "Max"))
    } else {     
      cat(sprintf("%6.0f%%", 100*probs[j]))
    }
  }
  cat("\n")
  for(i in 1:n.samples){  
    dist<-quantile(data$Data[,i], probs=probs)
    cat(sprintf("Sample %2.d: ", i))
    for(j in 1:n.probs){
      cat(sprintf(" %6.0f", dist[j]))
    }
    cat("\n")
  }
  cat("\n")
  if(print.diversity==TRUE){
    cat("Diversity indices\n")
  
    diversity.est<-estimateDiversity(data, samples=1:n.samples)
    method<-names(diversity.est[[1]])
    n.method<-length(method)
  
    cat("Sample")
    for(i in 1:n.samples){
      cat(sprintf("\t%6d", i))
    }
    cat("\n")
  
    for(m in method){
      cat(sprintf("%s", m))
      for(i in 1:n.samples){
        if(m=="Chao"){
          cat(sprintf("\t%6d", as.integer(round(diversity.est[[i]][[m]]))))
        } else {      
          cat(sprintf("\t%6.4f", diversity.est[[i]][[m]]))
        }
      }
      cat("\n")
    }
  }
}

freqPlot.family<-function(data, family, col="mistyrose", groups=NULL, groups.space=NULL, groups.color=NULL, ylim, main, xlab=""){

  if(missing(family)){  
    stop("You need to specify a family.")
  }
  
  if(missing(main)){
    main<-sprintf("%s:%s", family, data$Annotation[data$Annotation[,1]==family,2])
  }

  nSamples<-dim(data$Data)[2]
  
  if(!is.null(groups)){
    bar.colors<-groups.color[groups]
  } else { 
    bar.colors<-rep(col, nSamples)
  }

  family.sel<-data$Annotation[,1]==family
  
  if(sum(family.sel)==0){
    stop(sprintf("No data available for family %s.", family))
  }

  cur.data<-data$Data[family.sel,]
  counts.total<-apply(data$Data, 2, sum)
  cur.rate<-cur.data/counts.total

  if(missing(ylim)){
    ylim<-c(0, max(cur.rate*1.1))
  }

  #barplot(as.numeric(cur.rate), col=cols, width=1, names.arg=colnames(stat.families$Data), axes=FALSE, ylim=ylim, ylab="Normalized relative frequency", xlab=xlab, cex.lab=1.3, cex.main=1.3, main=main)
 
  barplot(as.numeric(cur.rate), col=bar.colors, width=1, names.arg=colnames(data$Data), axes=FALSE, ylim=ylim, ylab="Relative frequency", xlab=xlab, cex.lab=1.3, cex.main=1.3, main=main)


  for(i in 1:nSamples){  

    x.coords<-0.1+c(1.2*i-0.6)
    text(x=x.coords, y=cur.rate[i]+max(cur.rate)*0.02, labels=cur.data[i], col="grey30", cex=1.2)
    
  }

  y.seq<-seq(0, ylim[2], length=5)    
  axis(2, at=y.seq, labels=sprintf("%0.3f", y.seq), lwd=2, las=1, line=-1)

}

