\name{calculateRarefaction}
\alias{calculateRarefaction}
\title{Calculates rarefaction curves}
\description{
\code{calculateRarefaction} calculates rarefaction curves for one or several
samples.}
\usage{
calculateRarefaction(data, samples, iterations, x.seq)
}
\arguments{
\item{data}{a ShotgunFunctionalizeR data object}
\item{samples}{a vector with samples (column numbers)}
\item{iterations}{number of times the sampling should be repeated}
\item{x.seq}{a vector of values describing the sizes of the sub samples}}
\details{
Assume a set of \eqn{N} observation (e.g. reads) of \eqn{M} gene families.
Let \eqn{N_i} be
the number of observation for gene family \eqn{i} such that
\deqn{\sum_{i=1}^{M}N_i=N.}
Assume that a sub sample of size \eqn{n} is drawn and let \eqn{S_n} denote the number of unique gene
families. The rarefaction curve is then defined as
\deqn{\mbox{\bold{E}}\left[S_n\right]=M-\left(\begin{array}{c} N\\ n
\end{array}\right)\sum_{i=1}^{M}\left(\begin{array}{c}N-N_i \\ n
\end{array}\right).}
\code{calculateRarefaction} estimates the rarefaction curve by iteratively
sample the specified gene families and then generate a average curve.

Further details about rarefaction curve analysis can be found in
Hurlbert 1971 and Raup 1975.
}
\value{
\code{calculateRarefaction} returns a rarefaction curve (y-values) for the
specified x-values}
\seealso{
\code{\link{diversityPlot.family}}
}
\references{Hurlbert, S. H. (1971). The nonconcept of Species Diversity: A
Critique and Alternative Parameters. Ecology \bold{52} (4).

Raup, D. M. (1975). Taxonomic Diversity Estimation Using Rarefaction.
Paleobiology \bold{1} (4).}
\examples{
families.1<-list(Data=data.frame(rpois(1000, lambda=100)), Annotation=data.frame(paste("Gene Family", 1:1000)))
x.seq<-seq(10,5000, by=10)
curve<-calculateRarefaction(families.1, samples=1, iterations=100, x.seq=x.seq)
plot(x=x.seq, y=curve[[1]])
}
\keyword{nonparametric}
