\name{estimateDiversity}
\alias{estimateDiversity}
\title{Estimate diversity indices for a data set}
\description{
\code{estimateDiversity} estimates the Chao, Simpson and Shannon diversity
indices for a set of samples.
}
\usage{
estimateDiversity(data, samples=1,
                  method=c("chao", "simpson", "shannon"))
}
\arguments{
\item{data}{a ShotgunFunctionalizeR data object (e.g. produced by
\code{\link{readGeneFamilies}})}
\item{samples}{a vector indicating which samples to use (column numbers)}
\item{method}{a vector of methods (indices) to be calculate}}
\details{
The Chao estimator is non-parametric estimator for species (gene families)
richness (Chao 1984) of the following form
\deqn{
S^*=S_{obs}+\frac{a^2}{2b}
}
where \eqn{S_obS} is the total number of observed gene families, \eqn{a} is
number of gene families observed only once and \eqn{b} is the number of gene
families observed twice.

The Simpson index is a measure of diversity introduced in Simpson 1949. If
\eqn{N} is the total number of observations (reads), \eqn{S} the total number of
unique gene families and \eqn{n_i} the total number of observations for gene
family \eqn{i}, then the Simpson index \eqn{D} is defined as
\deqn{
D=1-\frac{\sum_{i=1}^{S} n_i(n_i-1)}{N(N-1)}
}

The Shannon index describes the diversity of categorical data and is defined
as
\deqn{
H'=-\sum_{i=1}^{S} p_i \mbox{ln}(p_i)
}
where \eqn{S} is the total number of unique gene families and \eqn{p_i} is
the relative frequency of gene family \eqn{i}.

Further details about diversity indices can be found in Hurlbert 1971.
}
\value{
\code{estimateDiversity} returns a list with one element for each specified
sample. For each sample, the specified indices are calculated and returned
as a list.}
\seealso{
\code{\link{diversityPlot.family}}, \code{\link{calculateRarefaction}}
}
\references{
Chao, A. (1984). Nonparametric estimation of the number of classes in a population. Scandinavian J. Stat. 11:265-270.

Hurlbert, S. H. (1971). The nonconcept of Species Diversity: A
Critique and Alternative Parameters. Ecology \bold{52} (4).

Simpson, E. H. (1949). Measurement of Diversity. Nature 163 (1949):688.
}
\examples{
estimateDiversity(list(Data=data.frame(c(3,2,1,1))))
estimateDiversity(list(Data=data.frame(c(3,2,2,1,1,1,1))))
}
\keyword{nonparametric}
