\name{groupPlot.category}
\alias{groupPlot.category}
\title{Plots the result from a pathway-centric direct comparison using the Poisson model}
\description{
\code{groupPlot.category} plots the result from a pathway-centric direct comparison of two groups.
The relative frequency for each sample and gene-function a specified the
category is shown. In addition, the estimated group-wise rate is drawn for
each group as a horizontal line. This function requires that the
Poisson model has been fitted to the data.
}
\usage{
groupPlot.category(stat.cat, category, ylim, 
                   col=c("mistyrose", "lavender", "red3", "royalblue3"), 
                   xlab="", main, print.pvalue=FALSE, 
                   print.pvalue.pos="topright",
                   print.pvalue.cex=1.3)
}
\arguments{
\item{stat.cat}{results from a direct comparison using the Poisson
model (\code{\link{testGeneCategories.dircomp}})}
\item{category}{a number indicating which gene family category to plot}
\item{ylim}{the limit of the y-axis. A suitable value is calculated if omitted}
\item{col}{character vector with four element indicating the colors of the
bars of the first group, the bars of the second group, the horizontal line
of the first group and the horizontal line of the second group}
\item{xlab}{label of the x-axis}
\item{main}{the title of the plot. If omitted, the annotation of the gene
family will be used}
\item{print.pvalue}{should the corresponding p-value be printed?}
\item{print.pvalue.pos}{where should be p-value be placed? This argument is
analogous to the location keywords used by \code{\link{legend}}.}
\item{print.pvalue.cex}{the magnification of the text used to print the
p-value}
}
\examples{
\dontrun{
data(MouseCOG)
po.stat<-testGeneCategories.dircomp(MouseCOG, pathway="cogpathways", 
         groups=c("Lean", "Lean", "Lean", "Obese", "Obese"))
groupPlot.category(po.stat, category=20)
}}
\seealso{
\code{\link{groupPlot}}, \code{\link{groupPlot.family}},
\code{\link{trendPlot}}, \code{\link{trendPlot.family}},
\code{\link{trendPlot.category}}
}
\keyword{hplot}
