\name{readGeneFamilies}
\alias{readGeneFamilies}
\title{Read a data file}
\description{
Reads a data file and creates a ShotgunFunctionalizeR data object.
}
\usage{
readGeneFamilies(file, type.family="detect", 
                 custom.annotation=NULL, sep="\t")
}
\arguments{
\item{file}{name of the file to be read}
\item{type.family}{type of gene family}
\item{sep}{field separator between the columns}
\item{custom.annotation}{file containing a custom annotation}
}
\details{
\code{readGeneFamilies} read a text file with metagenomic data and creates a
ShotgunFunctionalizeR data object for further analysis. The text file should be in ANSI format and
organized as follows. The left most column should be named 'GeneFamily' and
contain the identifiers for the type of gene family used. The following
columns should contain the counts for each of the samples. The first row
should contain the name of the samples. 

\code{readGeneFamilies} can detect which type of gene families that are
used (type.family='detect'). This is achieved matching identifiers against
those supported by ShotgunFunctionalizeR (currently clusters of orthologous
genes (COG), Enzyme Commission numbers (EC), Pfam protein domains and TIGRfam
protein domains.. Gene families of COG type are
assumed if no valid match can be made.

A custom gene family can be loaded by setting type.family to 'custom'. The
data file can then contain any form of identifiers. A custom annotation can
then be loaded by supplying an annotation file (e.g.
custom.annotation='myannotation.txt'). The custom annotation file should contain
two columns, one named 'GeneFamily' and one named 'Description', linking the identifiers with any form of description. 

See the User's Guide for more information. Example files are available at
http://shotgun.zool.gu.se.
}
\value{
\code{readGeneFamilies} returns a ShotgunFunctionalizeR data object.
}
\seealso{
\code{\link{writeRankings}}
}

\examples{
\dontrun{data<-readGeneFamilies("MetagenomicData.txt")}
}
\keyword{file}
