\name{testGeneCategories}
\alias{testGeneCategories}
\title{Performs a pathway-centric test for identification of significant
gene family categories}
\description{
\code{testGeneCategories} performs a pathway-centric analysis of a specified data set.
}
\usage{
testGeneCategories(data, method="gaussiansum",
                   category="cogpathways", samples=c(1,2),
                   multtest="BH", ord=TRUE,
                   enrichment.method="Binomial",enrichment.p=0.1,
                   design.matrix=NULL, coef=1,		   
                   covariates=NULL, log.covariates=FALSE, 
                   groups=NULL,
                   overdisp=FALSE)
}
\arguments{
\item{data}{A ShotgunFunctionalizeR data object}
\item{method}{Testing method to use. See details for more information}
\item{category}{Which type of gene category should be used?}
\item{samples}{A vector of samples to include}
\item{multtest}{Procedure for multiple testing correction. See details}
\item{ord}{Whether the resulting ranking list should be sorted with the most
significant gene categories at the top}
\item{enrichment.method}{Which method should be used for enrichment analysis}
\item{enrichment.p}{Which p-value cut-off should be used for enrichment
analysis}
\item{design.matrix}{Design matrix (general Poisson model)}
\item{coef}{Which coefficient from the design matrix should be tested for
significance (general Poisson model)}
\item{covariates}{Covariates for regression (Poisson regression model)}
\item{log.covariates}{Whether the covariates should be log transformed
(poisson regression model)}
\item{groups}{Vector of group labels for the direct comparison (Poisson model for direct
comparison)}
\item{overdisp}{Whether the poisson model use overdispersion (all poisson
models)}
}
\details{\code{testGeneCategories} supports a number of different
testing procedures. The \emph{method} argument can currently be set to the
following values
\itemize{
\item \emph{gaussiansum}. Performs the test using the Gaussian Sum
statistic. This procedure can only be performed for one pair of samples. See
\code{\link{testGeneCategories.gaussiansum}} for more information.
\item \emph{independence}. Performs a test of independence using Fisher's
exact test. This procedure can only be performed for one pair of samples. See
\code{\link{testGeneCategories.independence}} for more information.
\item \emph{enrichment}. Performs an enrichment analysis. First a
gene-centric analysis is performed which is followed by a test of
overrepresentation of gene-family categories among the significant gene
families. The \emph{enrichment.method} argument specifies the method to use
to rank the gene-families (see \code{\link{testGeneFamilies}}) and
\emph{enrichment.ph} the p-value cut-off. The test of overrepresentation is
performed using Fisher's exact test.
\item \emph{poisson}. The general Poisson model. To use this
procedure a design matrix describing the experimental setup is need. See the
User's Guide section 5.4.4 for an example.
\item \emph{poissonregression}. Performs a regression analysis using the
Poisson model. The \emph{covariates} argument, containing a vector with the
covariates, is needed to use this test. This method can also be called using
the \code{\link{testGeneCategories.regression}}.
\item \emph{poissongroups}. Performs a direct comparison between two groups
using the Poisson model. The vector \emph{groups} containing group labels
needs to be specified. Can also be called using
\code{\link{testGeneCategories.dircomp}}.
}

The \emph{multtest} argument specifies the procedure for adjusting the
p-value due to multiple testing. ShotgunFunctionalizeR currently utilizes
the \bold{multtest} package. See \code{\link{mt.rawp2adjp}} for information
about supported procedures.
}
\references{
Kristiansson, E., Hugenholtz, P., Dalevi, D. (2009). ShotgunFunctionalizeR:
an R-package for functional analysis of metagenomes. \emph{Bioinformatics}
25(20).

Dudoit, S., van der Laan, M.J. (2008). Multiple Testing Procedures with
Applications to Genomics. Springer Series in Statistics}
\examples{
\dontrun{
data(MouseCOG)
res.dircomp<-testGeneCategories(MouseCOG, method="poissongroups", category="COGPATHWAYS",
             groups=c("Lean", "Lean", "Lean", "Obese",  "Obese"))
}
\dontrun{
data(OceanEC)
res.reg<-testGeneCategories(OceanEC, method="poissonregression", category="KEGG", 
         covariates=c(10,70,130,200,500,770,4000), log.covariates=T)
}
\dontrun{
data(OceanEC)
res.enrichment<-testGeneCategories(OceanEC, method="enrichment", category="KEGG",
                samples=c(1,7), enrichment.p=0.05, enrichment.method="binomial")

}
}
\seealso{
\code{\link{testGeneCategories.gaussiansum}},
\code{\link{testGeneCategories.independence}},
\code{\link{testGeneCategories.enrichment}},
\code{\link{testGeneCategories.poisson}}
}
\keyword{htest}
