\name{testGeneCategories.poisson}
\alias{testGeneCategories.poisson}
\title{Performs a pathway-centric test using a Poisson model}
\description{
\code{testGeneCategories.poisson} performs a pathway-centric analysis of a
specified data set using a Poisson model. This procedures requires a user
specified design matrix.
}
\usage{
testGeneCategories.poisson(data, categories, 
                           design.matrix, coef, 
                           overdisp=FALSE)
}
\arguments{
\item{data}{A ShotgunFunctionalizeR data object}
\item{categories}{A list of categories (e.g. from \code{\link{getCategory}})}
\item{design.matrix}{A design matrix specifying the experimental setup}
\item{coef}{A number specifying which coefficient (column) in the design
matrix that should be tested}
\item{overdisp}{Should the Poisson model use overdispersion}
}
\details{
\code{testGeneCategories.poisson} provides a framework for performing
pathway-centric analysis using a Poisson model. The design matrix specifies
the experimental setup. Note that in pathway-centric analysis, each
gene-family in the category will have an individual baseline and hence, no
base line should be specified in the design matrix.

\code{testGeneCategories.regression} and \code{testGeneCategories.dircomp}
provides easy-to-use function for  regression analysis and
comparison of two groups respectively.

See Kristiansson et al 2009 for further details.
}
\examples{
Data<-matrix(rpois(n=80, lambda=rep((1:8)*10, each=10)), 
             nr=10, nc=8, byrow=FALSE)
colnames(Data)<-c("A1", "A2", "B1", "B2", "C1", "C2", "D1", "D2")
Annotation<-data.frame(GeneFamily=paste("GF", 1:10), 
                       Annotation=paste("GF", 1:10))

Data[3,1:2]<-Data[3,1:2]+10
Data[3,3:4]<-Data[3,3:4]+40

SimData<-list(Data=data.frame(Data), Annotation=Annotation, 
              Type="Custom")

summarizeData(SimData)

Design<-cbind(rep(1,8), c(rep(1,6), rep(0,2)), 
              c(rep(1,4), rep(0,4)), c(rep(1,2), rep(0,6)))
print(Design)

res.1<-testGeneFamilies(SimData, method="poisson", 
                        design.matrix=Design, coef=3)
res.2<-testGeneFamilies(SimData, method="poisson", 
                        design.matrix=Design, coef=4)
}
\seealso{
\code{\link{testGeneCategories}},
\code{\link{testGeneFamilies.poisson}},
\code{\link{testGeneCategories.regression}},
\code{\link{testGeneCategories.dircomp}}
}
\references{
Kristiansson, E., Hugenholtz, P., Dalevi, D. (2009). ShotgunFunctionalizeR:
an R-package for functional analysis of metagenomes. \emph{Bioinformatics}
25(20).
}
\keyword{htest}
