\name{testGeneFamilies}
\alias{testGeneFamilies}
\title{Performs a gene-centric test for identification of significant gene
families}
\description{
\code{testGeneCategories} performs a gene-centric analysis of a specified data set.
}
\usage{
testGeneFamilies(data, method="binomial", samples=c(1,2), 
                 multtest="BH", ord=TRUE, 
                 design.matrix=NULL, coef=1, 
                 covariates=NULL, log.covariates=FALSE, 
                 groups=NULL,
                 overdisp=FALSE)
}
\arguments{
\item{data}{A ShotgunFunctionalizeR data object}
\item{method}{Testing method to use. See details for more information}
\item{samples}{A vector of samples to include}
\item{multtest}{Procedure for multiple testing correction. See details for
more information}
\item{ord}{Whether the resulting ranking list should be sorted with the most
significant gene families at the top}
\item{design.matrix}{Design matrix (general poisson model)}
\item{coef}{Which coefficient from the design matrix should be tested for
significance (general Poisson model)}
\item{covariates}{Covariates for regression (Poisson regression model)}
\item{log.covariates}{Whether the covariates should be log transformed
(poisson regression model)}
\item{groups}{Vector of group labels for the direct comparison (Poisson model for direct
comparison)}
\item{overdisp}{Whether the poisson model use overdispersion (all poisson
models)}
}
\details{\code{testGeneFamilies} supports a wide range of testing
procedures. The \emph{method} argument can currently be set to the 
following values
\itemize{
\item \emph{binomial}. Performs a binomial test for a pair of metagenomes.
See \code{\link{testGeneFamilies.binomial}} for more information.
\item \emph{hypergeometric}. Performs a hypergeometric test for a pair of
metagenomes. See \code{\link{testGeneFamilies.hypergeometric}} for more
information.
\item \emph{gaussian}. Perform a Gaussian test for a pair of metagenomes.
This test is only valid asymptotically and should thus only be applied when
the number of observations is sufficiently large. See
\code{link{testGeneFamilies.gaussian}} for more information.
\item \emph{poisson}. The general Poisson model. To use this
procedure a design matrix describing the experimental setup is need. See the
User's Guide section 5.4.4 for an example.
\item \emph{poissonregression}. Performs a regression analysis using the
Poisson model. The \emph{covariates} argument, containing a vector with the
covariates, is needed to use this test. This method can also be called using
the \code{\link{testGeneFamilies.regression}}.
\item Performs a direct comparison between two groups
using the Poisson model. The vector \emph{groups} containing group labels
needs to be specified. Can also be called using
\code{\link{testGeneFamilies.dircomp}}.
}
The \emph{multtest} argument specifies the procedure for adjusting the
p-value due to multiple testing. ShotgunFunctionalizeR currently utilizes
the \bold{multtest} package. See \code{\link{mt.rawp2adjp}} for information
about supported procedures.
}
\references{
Kristiansson, E., Hugenholtz, P., Dalevi, D. (2009). ShotgunFunctionalizeR:
an R-package for functional analysis of metagenomes. \emph{Bioinformatics}
25(20).

Dudoit, S., van der Laan, M.J. (2008). Multiple Testing Procedures with
Applications to Genomics. Springer Series in Statistics
}
\examples{
\dontrun{
data(OceanCOG)
res.bin<-testGeneFamilies(OceanCOG, method="Binomial", samples=c(1,7))
}
\dontrun{
data(OceanPFAM)
res.reg<-testGeneFamilies(OceanPFAM, method="poissonregression",
         covariates=c(10,70,130,200,500,770,4000), log.covariate=T)
}
\dontrun{
data(MouseEC)
res.dircomp<-testGeneFamilies(MouseEC, method="poissongroups",
             groups=c("Lean", "Lean", "Lean", "Obese", "Obese"))
}
}
\seealso{
\code{\link{readGeneFamilies}},
\code{\link{testGeneFamilies.binomial}},
\code{\link{testGeneFamilies.hypergeometric}},
\code{\link{testGeneFamilies.gaussian}},
\code{\link{testGeneFamilies.poisson}}
}
\keyword{htest}
