\name{testGeneFamilies.binomial}
\alias{testGeneFamilies.binomial}
\title{Performs a gene-centric analysis using a binomial test}
\description{
\code{testGeneFamilies.binomial} performs a gene-centric analysis of a
specified data set using a binomial test.
}
\usage{
testGeneFamilies.binomial(data, samples)
}
\arguments{
\item{data}{a ShotgunFunctionalizeR data object}
\item{samples}{vector of samples (column numbers) to use in the analysis}
}
\details{
\code{testGeneFamilies.binomial} performs an exact binomial test for each row
in the data matrix. Assume that \eqn{X_1\sim Po(M_1p_1)} and \eqn{X_2\sim
Po(M_2p_2)} where \eqn{M_1} and \eqn{M_2} are the total number of
observations from two metagenomes. It follows that 
\deqn{
X_1|X_1+X_2=n \sim Bin\left(n,\frac{M_1p_1}{M_1p_1+M_2p_2}\right)
}
and the binomial test is testing whether \eqn{p_1=p_2}. The test can be seen
as an approximation of the hypergeometric counterpart
(\code{\link{testGeneFamilies.hypergeometric}}). 

\code{testGeneFamilies.binomial} is usually called 
implicitly by using the 'binomial' method in \code{\link{testGeneFamilies}}.

Further details are available in Kristiansson et al 2009.
}
\value{\code{testGeneFamilies.binomial} returns a list with the following
elements
\item{PValues}{A list of p-values}
\item{Rankings.detail}{A list additional elements containing details about
the ranking}
}
\seealso{
\code{\link{testGeneFamilies}}
}
\references{
Kristiansson, E., Hugenholtz, P., Dalevi, D. (2009). ShotgunFunctionalizeR:
an R-package for functional analysis of metagenomes. \emph{Bioinformatics}
25(20).
}
\examples{
counts<-cbind(rpois(10, 100), rpois(10, seq(50,300, length=10)))
SimData<-list(Data=counts)
testGeneFamilies.binomial(SimData, samples=c(1,2))
}
\keyword{htest}
