\name{testGeneFamilies.gaussian}
\alias{testGeneFamilies.gaussian}
\title{Performs a gene-centric analysis using a Gaussian test}
\description{
\code{testGeneFamilies.gaussian} performs a gene-centric analysis of a
specified data set using a Gaussian.
}
\usage{
testGeneFamilies.gaussian(data, samples)
}
\arguments{
\item{data}{a ShotgunFunctionalizeR data object}
\item{samples}{vector of samples (column numbers) to use in the analysis}
}
\details{
\code{testGeneFamilies.gaussian} tests for significant gene
families between two samples by using a Binomial-Gaussian approximation.
Let \eqn{X_1} and \eqn{X_r} be the number of observations from sample 1 and
2 and let \eqn{N_1} and \eqn{N_2} is the total number of observations in
each sample respectively. If we define
\deqn{
D=\frac{R_1-R_2}{\sqrt{PQ\left(\frac{1}{N_1}+\frac{1}{N_2}\right)}}
}
where \eqn{R_1=X_1/N_1}, \eqn{R_2=X_2/N_2},
\deqn{
P=\frac{X_1+X_2}{N_1+N_2}
}
and \eqn{Q=1-P} it follows that D is approximately normal with expected
value \eqn{0} and variance \eqn{1} (according to the central limit theorem).
Hence, we can test whether the relative frequency of reads in sample 1
differs form sample 2 by testing \eqn{\mbox{H}_0: D=0} versus
\eqn{\mbox{H}_1: D\neq0}.

More details are available in Kristiansson et al 2009.
}
\value{
\code{testGeneFamilies.binomial} returns a list with the following
elements
\item{PValues}{A list of p-values}
\item{Rankings.detail}{A list additional elements containing details about
the ranking}
}
\references{
Kristiansson, E., Hugenholtz, P., Dalevi, D. (2009). ShotgunFunctionalizeR:
an R-package for functional analysis of metagenomes. \emph{Bioinformatics}
25(20).
}
\seealso{
\code{\link{testGeneFamilies}}
}
\examples{
counts<-cbind(rpois(10, 100), rpois(10, seq(50,300, length=10)))
SimData<-list(Data=counts)
testGeneFamilies.gaussian(SimData, samples=c(1,2))
}
\keyword{htest}
