\name{testGeneFamilies.hypergeometric}
\alias{testGeneFamilies.hypergeometric}
\title{Performs a gene-centric analysis using a hypergeometric test}
\description{
\code{testGeneFamilies.hypergeometric} performs a gene-centric analysis of a
specified data set using a hypergeometric test.
}
\usage{
testGeneFamilies.hypergeometric(data, samples)
}
\arguments{
\item{data}{A ShotgunFunctionalizeR data object}
\item{samples}{vector of samples (column numbers) to use in the analysis}
}
\details{
\code{testGeneFamilies.binomial} performs an exact hypergeometric test for each row of
in the data matrix. Under the assumption that the counts from both
metagenomes follows a multinomial distribution, the procedure test whether
\eqn{p_{i1}=p_{i2}} for each row \eqn{i=1, \ldots, n}. If \eqn{X_{i1}} and \eqn{X_{i2}} are
the counts for row \eqn{i} and metagenome 1 and 2 respectively, it follows that
\deqn{
X_{i1}|X_{i1}+X_{i2}=n \sim Hyper(M_1+M_2, M_1, n)
}
where \eqn{M_1} and \eqn{M_2} are the total number of counts in metagenome 1 and 2
respectively. The function \code{\link{testGeneFamilies.binomial}}
provides a faster binomial approximation. 

\code{testGeneFamilies.hypergeometric} is usually called 
implicitly by using the 'binomial' method in \code{\link{testGeneFamilies}}.

Further details are available in Kristiansson et al 2009.
}
\value{\code{testGeneFamilies.binomial} returns a list with the following
elements
\item{PValues}{A list of p-values}
\item{Rankings.detail}{A list additional elements containing details about
the ranking}
}
\examples{
counts<-cbind(rpois(10, 100), rpois(10, seq(50,300, length=10)))
SimData<-list(Data=counts)
testGeneFamilies.hypergeometric(SimData, samples=c(1,2))
}
\references{
Kristiansson, E., Hugenholtz, P., Dalevi, D. (2009). ShotgunFunctionalizeR:
an R-package for functional analysis of metagenomes. \emph{Bioinformatics}
25(20).
}
\seealso{
\code{\link{testGeneFamilies}}
}
\keyword{htest}
