\name{testGeneFamilies.poisson}
\alias{testGeneFamilies.poisson}
\title{Performs a gene-centric test using a Poisson model}
\description{
Test for significant gene families using the poisson model
}
\usage{
testGeneFamilies.poisson(data, design.matrix, 
                         coef, overdisp=FALSE)
}
\arguments{
\item{data}{A ShotgunFunctionalizeR data object}
\item{design.matrix}{A design matrix specifying the experimental setup}
\item{coef}{A number specifying which coefficient (column) in the design
matrix that should be tested}
\item{overdisp}{Should the Poisson model use overdispersion}
}
\details{
\code{testGeneFamilies.poisson} provides a general framework for performing
gene-centric analysis using a Poisson model. The design matrix specifies
the experimental setup. 

\code{testGeneCategories.regression} and \code{testGeneCategories.dircomp}
provides easy-to-use function for  regression analysis and
comparison of two groups respectively.

See Kristiansson et al 2009 for further details.
}
\seealso{
\code{\link{testGeneFamilies}},
\code{\link{testGeneCategories.poisson}},
\code{\link{testGeneFamilies.regression}},
\code{\link{testGeneFamilies.dircomp}}
}
\examples{
Data<-matrix(rpois(n=80, lambda=rep((1:8)*10, each=10)), 
             nr=10, nc=8, byrow=FALSE)
colnames(Data)<-c("A1", "A2", "B1", "B2", "C1", "C2", "D1", "D2")
Annotation<-data.frame(GeneFamily=paste("GF", 1:10), 
                       Annotation=paste("GF", 1:10))

Data[3,1:2]<-Data[3,1:2]+10
Data[3,3:4]<-Data[3,3:4]+40

SimData<-list(Data=data.frame(Data), Annotation=Annotation, 
              Type="Custom")

summarizeData(SimData)

Design<-cbind(rep(1,8), c(rep(1,6), rep(0,2)), 
              c(rep(1,4), rep(0,4)), c(rep(1,2), rep(0,6)))
print(Design)

res.1<-testGeneFamilies(SimData, method="poisson", 
                        design.matrix=Design, coef=3)
res.2<-testGeneFamilies(SimData, method="poisson", 
                        design.matrix=Design, coef=4)
}
\references{
Kristiansson, E., Hugenholtz, P., Dalevi, D. (2009). ShotgunFunctionalizeR:
an R-package for functional analysis of metagenomes. \emph{Bioinformatics}
25(20).
}
\keyword{htest}
